@@ -3,16 +3,17 @@ import sys
 import os
 
 TOKEN = os.getenv("NOTION_TOKEN")
+SPACE_ID = os.getenv("NOTION_SPACE_ID")
 
 
 def write_blog(prompt: str):
-    ai = NotionAI(TOKEN)
+    ai = NotionAI(TOKEN, SPACE_ID)
     res = ai.blog_post(prompt)
     print(res)
 
 
 def write_blog_stream(prompt: str):
-    ai = NotionAIStream(TOKEN)
+    ai = NotionAIStream(TOKEN, SPACE_ID)
     res = ai.blog_post(prompt)
     for item in res:
         sys.stdout.write(item)
