@@ -5,7 +5,7 @@ import requests
 
 from notionai.enums import PromptTypeEnum, ToneEnum, TopicEnum, TranslateLanguageEnum
 
-MODEL = "openai-1.1"
+MODEL = "openai-3"
 URL = "https://www.notion.so/api/v3/getCompletion"
 
 
@@ -15,16 +15,19 @@ class NotionAIBase(object):
     def __init__(
         self,
         token: str,
+        space_id: str,
         model: str = MODEL,
     ) -> None:
         """Init NotionAI
         Args:
             token (str): Notion token_v2
+            space_id (str): Notion workspace id
             model (str, optional): AI model. Default to openai-1.1
             stream (bool, optional): use stream result. Defaults to False.
             pageTitle (str, optional): Title for your content. Defaults to PAGE_TITLE.
         """
         self.token = token
+        self.space_id = space_id
         self.model = model
         self.is_space_permission = False
         self.url = URL
@@ -33,24 +36,27 @@ class NotionAIBase(object):
         payload = {
             "id": self._get_id(),
             "model": self.model,
-            "spaceId": str(uuid.uuid4()),
+            "spaceId": self.space_id,
             "isSpacePermission": self.is_space_permission,
             "context": content,
         }
 
-        cookies = [
-            "token_v2=" + self.token,
-        ]
-
-        headers = {
-            "Cookie": "; ".join(cookies),
-            "Content-Type": "application/json",
-        }
-
+        headers = self._build_headers(self.token)
         return requests.post(
             self.url, json=payload, headers=headers, stream=self.stream
         )
 
+    def _build_headers(self, token: str):
+        cookies = [
+            "token_v2=" + token,
+        ]
+
+        return {
+            "accept": "application/json",
+            "Cookie": "; ".join(cookies),
+            "Content-Type": "application/json",
+        }
+
     def _post(self, content: dict) -> str:
         r = self._request(content)
         data = r.text.split("\n")
@@ -72,6 +78,35 @@ class NotionAIBase(object):
 
 
 class NotionAI(NotionAIBase):
+    @classmethod
+    def get_spaces(cls, token: str) -> list[dict]:
+        """Get all spaces
+        Params:
+            token (str): Notion token_v2
+
+        Returns:
+            list[dict]: list of spaces with id and name
+
+        Example: [
+            {"id": "space_id_1", "name": "space_name"},
+            {"id": "space_id_2", "name": "space_name"}
+        ]
+        """
+        url = "https://www.notion.so/api/v3/getSpaces"
+        r = requests.post(url, headers=cls._build_headers(token))
+        if r.status_code != 200:
+            raise ValueError("Cannot get spaces")
+        res = r.json()
+        spaces = []
+        for _, val in res.items():
+            space = val.get("space")
+            if space:
+                for k, v in space.items():
+                    space_id = k
+                    space_name = v["value"]["name"]
+                    spaces.append({"id": space_id, "name": space_name})
+        return spaces
+
     def writing_with_topic(self, topic: TopicEnum, prompt: str) -> str:
         """Writing for special topic
 
